io.github.fdero:bits4j 1.0.1 API

Packages
Package
Description
This package contains classes that provide the core functionalities of the bits4j library.
This package contains classes that provide a way to input and output bits using InputStream and OutputStream.